@@ -109,7 +109,7 @@ class Witter():
         self.scrolled_window = self.wTree.get_widget("scrolled_window")
         self.vbox.reparent(self.window)
 
-        
+        self.urlmenu = self.build_right_click_menu()
         # create a menu object by calling a method to deine it
         self.menu = self.create_menu(self.scrolled_window)
         # add the menu to the window
@@ -122,7 +122,7 @@ class Witter():
         self.last_mention_id=None
         self.last_public_id=None
         
-        self.urlmenu = gtk.Menu()
+        #self.urlmenu = gtk.Menu()
         # define a liststore we use this to store our tweets and some associated data
         # the fields are : Name,nameColour,Tweet+Timestamp,TweetColour,id, type
         self.liststore = gtk.ListStore(str, str, str, str, str, str)
@@ -199,7 +199,7 @@ class Witter():
         selection = self.treeview.get_selection()
         selection.connect('changed', self.build_menu)
 
-       # self.treeview.connect("changed", self.build_menu, None);
+        # self.treeview.connect("changed", self.build_menu, None);
         self.treeview.tap_and_hold_setup(self.urlmenu, callback=gtk.tap_and_hold_menu_position_top)
        
         #we are going to keep a list of the URLs we've found and used in the menu
@@ -225,8 +225,8 @@ class Witter():
         menuItemTwitPic.connect("activate", self.selectImage)
         menuItemTrends = gtk.MenuItem("Trends")
         menuItemTrends.connect("activate", self.switchViewTo, "trends")
-        menuItemSearch = gtk.MenuItem("Search")
-        menuItemSearch.connect("activate", self.switchViewTo, "search")
+        menuItemPublic = gtk.MenuItem("Public")
+        menuItemPublic.connect("activate", self.switchViewTo, "public")
         menuItemCreds = gtk.MenuItem("Set UID/PWD")
         menuItemCreds.connect("activate",self.promptForCredentials)
         menuItemSeparator = gtk.SeparatorMenuItem()
@@ -237,7 +237,7 @@ class Witter():
         menu.append(menuItemTweet)
         menu.append(menuItemTwitPic)
         menu.append(menuItemTrends)
-        menu.append(menuItemSearch)
+        menu.append(menuItemPublic)
         menu.append(menuItemSeparator)
         menu.append(menuItemCreds)
         menu.append(menuItemExit)
@@ -620,13 +620,30 @@ class Witter():
                 #wider
                 self.cell.set_property('wrap-width', 630)
                 
-   
+    def build_right_click_menu(self, *args):
+        #build the layout for the right click menu
+        urlmenu = gtk.Menu()
+        self.menuItemURL = gtk.MenuItem("URL actions")
+        
+        urlmenu.append(self.menuItemURL)
+        self.menuItemURL.show()
+        #regardless we should provide the option to follow/unfollow/reply to/dm user?
+        self.menuItemUserAction = gtk.MenuItem("User Actions")
+        
+        urlmenu.append(self.menuItemUserAction)
+        self.menuItemUserAction.show()
+        #unfollow
+        
+         
+        return urlmenu 
          
     def build_menu(self, widget, *args):
         #a fairly standard menu create
         #I put in the same options as I have buttons
         # and linked to the same methods
-        
+        self.menuItemURL.remove_submenu()
+        self.menuItemUserAction.remove_submenu()
+               
         treeselection = self.treeview.get_selection()
         select1, select2 = treeselection.get_selected_rows()
         #entry1, entry2 = self.treeview.get_selection().get_selected()
@@ -646,15 +663,24 @@ class Witter():
                         #find the 'word' which is our url
                         if re.search("http", word):
                             url=word
-                            if re.search(url, self.ListedURLS):
-                                 #already added this url so don't bother
-                                print "URL already in menu"
-                            else:    
-                                menuItemLaunchURL = gtk.MenuItem(name+": "+url)
-                                menuItemLaunchURL.connect("activate", self.openBrowser, url )
-                                self.urlmenu.append(menuItemLaunchURL)
-                                menuItemLaunchURL.show()
-                                self.ListedURLS=self.ListedURLS+url
+                            menuUrls = gtk.Menu()
+                            menuItemLaunchURL = gtk.MenuItem(url)
+                            menuItemLaunchURL.connect("activate", self.openBrowser, url )
+                            menuUrls.append(menuItemLaunchURL)
+                            menuUrls.show()
+                            self.menuItemURL.set_submenu(menuUrls)
+                            
+                    
+                menuUserAct = gtk.Menu()        
+                menuItemFollowUser = gtk.MenuItem("Follow: "+name)                 
+                menuItemFollowUser.connect("activate", self.FollowUser, name)
+                menuItemUnFollowUser = gtk.MenuItem("Unfollow: "+name)
+                menuItemUnFollowUser.connect("activate", self.UnFollowUser, name)
+                menuUserAct.append(menuItemFollowUser)
+                menuUserAct.append(menuItemUnFollowUser)
+                menuUserAct.show()
+                self.menuItemUserAction.set_submenu(menuUserAct)
+                
         except IndexError:
             print "nothing selected"
            
@@ -663,6 +689,59 @@ class Witter():
         self.urlmenu.show_all()
         
     
+    def FollowUser(self, widget, name, *args  ):
+        print "follow: " + name
+        
+        post = urllib.urlencode({ 'screen_name' : name })
+                
+        #build the request with the url and our post data
+        req = urllib2.Request('http://twitter.com/friendships/create.json', post)
+        
+        auth_handler = urllib2.HTTPBasicAuthHandler()
+        #realm here is important. or at least it seemed to be
+        #this info is on the login box if you go to the url in a browser
+        
+        auth_handler.add_password(realm='Twitter API',
+                          uri='http://twitter.com/friendships/create.json',
+                          user=self.username,
+                          passwd=self.password)
+        #we create an 'opener' object with our auth_handler
+        opener = urllib2.build_opener(auth_handler)
+        # ...and install it globally so it can be used with urlopen.
+        urllib2.install_opener(opener)
+        #switch on whether this is an refresh or a first download
+       
+        json = urllib2.urlopen(req)
+        #JSON is awesome stuff. we get given a long string of json encoded information
+        #which contains all the tweets, with lots of info, we decode to a json object
+        data = simplejson.loads(json.read())
+        print data
+        
+    def UnFollowUser(self, widget, name, *args ):
+        print "unfollow : " + name
+        post = urllib.urlencode({ 'screen_name' : name })
+                
+        #build the request with the url and our post data
+        req = urllib2.Request('http://twitter.com/friendships/destroy.json', post)
+        
+        auth_handler = urllib2.HTTPBasicAuthHandler()
+        #realm here is important. or at least it seemed to be
+        #this info is on the login box if you go to the url in a browser
+        auth_handler.add_password(realm='Twitter API',
+                          uri='http://twitter.com/friendships/destroy.json',
+                          user=self.username,
+                          passwd=self.password)
+        #we create an 'opener' object with our auth_handler
+        opener = urllib2.build_opener(auth_handler)
+        # ...and install it globally so it can be used with urlopen.
+        urllib2.install_opener(opener)
+        #switch on whether this is an refresh or a first download
+       
+        json = urllib2.urlopen(req)
+        #JSON is awesome stuff. we get given a long string of json encoded information
+        #which contains all the tweets, with lots of info, we decode to a json object
+        data = simplejson.loads(json.read())
+        print data
     
     def openBrowser(self, widget, url, *args):      
         #open a url in a browser
@@ -677,12 +756,12 @@ class Witter():
         #we want to see if we're on fremantle or not as the default colour
         #scheme has changed
         #look for /etc/maemo_version
-        print "checking for /etc/maemo_version"
+        print "checking for /proc/component_version"
         try:
-            f = open('/etc/maemo_version', 'r')
+            f = open('/proc/component_version', 'r')
             read_data = f.read()
-            if (re.search("5.0 Fremantle", read_data)):
-                print "found maemo 5"
+            if (re.search("RX-51", read_data)):
+                print "found n900"
                 self.tweetcolour= "#FFFFFF"
                 self.namecolour="#FE00B8"
                 self.defaultwidth=560
